@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 2024-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: Apache-2.0
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -127,6 +127,16 @@ static EGLBoolean LoadProcHelper(EplPlatformData *plat, void *handle, void **ptr
     return EGL_TRUE;
 }
 
+static struct gbm_bo *fallback_gbo_create_with_modifiers2(struct gbm_device *gbm,
+        uint32_t width, uint32_t height,
+        uint32_t format,
+        const uint64_t *modifiers,
+        const unsigned int count,
+        uint32_t flags)
+{
+    return gbm_bo_create_with_modifiers(gbm, width, height, format, modifiers, count);
+}
+
 EGLBoolean eplX11LoadEGLExternalPlatformCommon(int major, int minor,
         const EGLExtDriver *driver, EGLExtPlatform *extplatform,
         EGLint platform_enum)
@@ -135,9 +145,15 @@ EGLBoolean eplX11LoadEGLExternalPlatformCommon(int major, int minor,
     EGLBoolean timelineSupported = EGL_TRUE;
     pfn_eglPlatformGetVersionNVX ptr_eglPlatformGetVersionNVX;
 
-    // Before we do anything else, make sure that we've got a recent enough
-    // version of libgbm.
-    if (dlsym(RTLD_DEFAULT, "gbm_bo_create_with_modifiers2") == NULL)
+    /*
+     * Before we do anything else, make sure that we've got a recent enough
+     * version of libgbm. The most recent thing we depend on is
+     * GBM_BO_IMPORT_FD_MODIFIER, which we can't check directly.
+     *
+     * But, gbm_bo_get_bpp was added at about the same time, so we can check
+     * for that instead.
+     */
+    if (dlsym(RTLD_DEFAULT, "gbm_bo_get_bpp") == NULL)
     {
         return EGL_FALSE;
     }
@@ -226,6 +242,14 @@ EGLBoolean eplX11LoadEGLExternalPlatformCommon(int major, int minor,
 
 #undef LOAD_PROC
 
+    // Load gbm_bo_create_with_modifiers2 if it's available. If it's not, then
+    // we'll fall back to using gbm_bo_create_with_modifiers.
+    plat->priv->gbm.bo_create_with_modifiers2 = dlsym(RTLD_DEFAULT, "gbm_bo_create_with_modifiers2");
+    if (plat->priv->gbm.bo_create_with_modifiers2 == NULL)
+    {
+        plat->priv->gbm.bo_create_with_modifiers2 = fallback_gbo_create_with_modifiers2;
+    }
+
     eplPlatformBaseInitFinish(plat);
     return EGL_TRUE;
 }
@@ -476,6 +500,7 @@ static EGLDeviceEXT FindDeviceForFD(EplPlatformData *plat, int fd)
                 if (version->name != NULL)
                 {
                     if (strcmp(version->name, "nvidia-drm") == 0
+                            || strcmp(version->name, "tegradisp-drm") == 0
                             || strcmp(version->name, "tegra-udrm") == 0
                             || strcmp(version->name, "tegra") == 0)
                     {
