@@ -362,7 +362,7 @@ static X11ColorBuffer *AllocOneColorBuffer(X11DisplayInstance *inst,
     glvnd_list_init(&buffer->entry);
     buffer->fd = -1;
 
-    buffer->gbo = gbm_bo_create_with_modifiers2(inst->gbmdev,
+    buffer->gbo = inst->platform->priv->gbm.bo_create_with_modifiers2(inst->gbmdev,
             width, height, fmt->fourcc, modifiers, num_modifiers, flags);
 
     if (buffer->gbo == NULL)
@@ -1710,7 +1710,6 @@ static EGLBoolean WaitImplicitFence(EplDisplay *pdpy, X11ColorBuffer *buffer)
     if (fd >= 0)
     {
         success = WaitForSyncFDGPU(pdpy->priv->inst, fd);
-        close(fd);
     }
 
     if (success)
@@ -1886,11 +1885,14 @@ static EGLBoolean WaitTimelinePoint(X11DisplayInstance *inst, X11Timeline *timel
                     &timeline->handle, &timeline->point, 1, INT64_MAX,
                     DRM_SYNCOBJ_WAIT_FLAGS_WAIT_FOR_SUBMIT,
                     &first) == 0)
+        {
+            success = EGL_TRUE;
+        }
+        else
         {
             eplSetError(inst->platform, EGL_BAD_ALLOC,
                     "Internal error: drmSyncobjTimelineWait(WAIT_FOR_SUBMIT) failed: %s\n",
                     strerror(errno));
-            success = EGL_TRUE;
         }
     }
 
@@ -2382,7 +2384,7 @@ EGLBoolean eplX11SwapInterval(EGLDisplay edpy, EGLint interval)
         {
             // If we don't recognize he current EGLSurface, then just pass the
             // call through to the driver.
-            ret = pdpy->platform->priv->egl.SwapInterval(edpy, interval);
+            ret = pdpy->platform->priv->egl.SwapInterval(pdpy->internal_display, interval);
         }
     }
     else
